==> xfxwidgets-1.7.26.tar.gz: lib/xMediaItem.dart <==
﻿import 'dart:typed_data';
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:xfxbase/XFDataItem.dart';
import 'package:xfxwidgets/xMediaItem.dart';

///
///XMediaItem
class XMediaItem extends XFDataItem {
  @override
  String? get X_nome => "XMediaItem";
  @override
  String? get X_nomeMF => "F";
  @override
  String? get X_nomePlurale => "XMediaItem";
  @override
  String? get X_docCaption => "XMediaItem";
  static final String tableName = 'XMediaItem';
  static final XProp blobURL_XP = XProp('blobURL', 'bloblURL', Color.fromARGB(255, 0, 0, 0));

  ///
  /// Note:Deciso e fillato da API
  /// 'bloblURL'
  String? blobURL;
  static final XProp hasOverlaySurface_XP = XProp('hasOverlaySurface', 'hasOverlaySurface', Color.fromARGB(255, 0, 0, 0));

  /// 'hasOverlaySurface'
  bool? hasOverlaySurface;
  static final XProp localURI_XP = XProp('localURI', 'localURI', Color.fromARGB(255, 0, 0, 0));

  /// 'localURI'
  String? localURI;
  static final XProp mediaType_XP = XProp('mediaType', 'Tipo', Color.fromARGB(255, 0, 0, 0));

  /// S= sost, U = Usateo, G = generale
  ///
  /// ToolTip:S= sost, U = Usateo, G = generale
  /// 'Tipo'
  int? mediaType;
  static final XProp miniatura_XP = XProp('miniatura', 'miniatura', Color.fromARGB(255, 0, 0, 0));

  /// 'miniatura'
  Uint8List? miniatura;
  static final XProp overlaySurface_XP = XProp('overlaySurface', 'overlaySurface', Color.fromARGB(255, 0, 0, 0));

  /// Bitmap trasp con di segni dell'utente che si sovrappone al payload
  ///
  /// Note:lo svuotiamo nelle API e lo mettiamo nel BLOB
  ///
  /// ToolTip:Bitmap trasp con di segni dell'utente che si sovrappone al payload
  /// 'overlaySurface'
  Uint8List? overlaySurface;
  static final XProp payload_XP = XProp('payload', 'Payload', Color.fromARGB(255, 0, 0, 0));

  ///
  /// Note:lo svuotiamo nelle API e lo mettiamo nel BLOB
  /// 'Payload'
  Uint8List? payload;
  static final XProp visPos_XP = XProp('visPos', 'Pos', Color.fromARGB(255, 0, 0, 0));

  /// 'Pos'
  int? visPos;
  static final XProp xDocID_XP = XProp('xDocID', 'Riferimento', Color.fromARGB(255, 248, 227, 140));

  /// ID del XDoc al quale è legato questo file
  ///
  /// ToolTip:ID del XDoc al quale è legato questo file
  /// 'Riferimento'
  String? xDocID;
  String? xDocID_resolved;
  static final String colnamexDocID_resolved = 'xDocID_resolved';
  static final XProp xDocType_XP = XProp('xDocType', 'xDocType', Color.fromARGB(255, 0, 0, 0));

  /// nome del Attore (XDoc)
  ///
  /// ToolTip:nome del Attore (XDoc)
  /// 'xDocType'
  String? xDocType;

  XMediaItem(super.id, {this.blobURL = "", this.hasOverlaySurface = false, this.localURI = "", this.mediaType = 0, this.miniatura, this.overlaySurface, this.payload, this.visPos = 0, this.xDocID = "", this.xDocID_resolved = "", this.xDocType = "", super.isNew = false, super.isModified = false}) {}

  factory XMediaItem.fromJson(Map<String, dynamic> jsonData) {
    return XMediaItem(
      jsonData['id'],
      blobURL: jsonData['blobURL'],
      hasOverlaySurface: jsonData['hasOverlaySurface'],
      localURI: jsonData['localURI'],
      mediaType: jsonData['mediaType'] == null ? 0 : int.parse(jsonData['mediaType'].toString()),
      miniatura: (jsonData['miniatura'] == null ? null : base64.decode(jsonData['miniatura'])),
      overlaySurface: (jsonData['overlaySurface'] == null ? null : base64.decode(jsonData['overlaySurface'])),
      payload: (jsonData['payload'] == null ? null : base64.decode(jsonData['payload'])),
      visPos: jsonData['visPos'] == null ? 0 : int.parse(jsonData['visPos'].toString()),
      xDocID: jsonData['xDocID'],
      xDocID_resolved: jsonData['xDocID_resolved'],
      xDocType: jsonData['xDocType'],
    );
  }

  Map<String, dynamic> toJson() => {
        'blobURL': this.blobURL,
        'hasOverlaySurface': this.hasOverlaySurface,
        'id': this.id,
        'localURI': this.localURI,
        'mediaType': this.mediaType,
        'miniatura': this.miniatura,
        'overlaySurface': this.overlaySurface,
        'payload': this.payload,
        'visPos': this.visPos,
        'xDocID_resolved': this.xDocID_resolved,
        'xDocID': this.xDocID == null || this.xDocID == '' ? '00000000-0000-0000-0000-000000000000' : this.xDocID,
        'xDocType': this.xDocType,
      };

  @override
  XMediaItem getCloneFull() {
    var r = XMediaItem(this.id);
    r.copyProps(this, r);
    return r;
  }

  @override
  copyProps(dynamic objectFrom, dynamic objTO) {
    objTO.isNew = objectFrom.isNew;
    objTO.isModified = objectFrom.isModified;

    objTO.blobURL = objectFrom.blobURL;
    objTO.hasOverlaySurface = objectFrom.hasOverlaySurface;
    objTO.id = objectFrom.id;
    objTO.localURI = objectFrom.localURI;
    objTO.mediaType = objectFrom.mediaType;
    objTO.miniatura = objectFrom.miniatura;
    objTO.overlaySurface = objectFrom.overlaySurface;
    objTO.payload = objectFrom.payload;
    objTO.visPos = objectFrom.visPos;
    objTO.xDocID = objectFrom.xDocID;
    objTO.xDocID_resolved = objectFrom.xDocID_resolved;
    objTO.xDocType = objectFrom.xDocType;
  }

  @override
  dynamic getProp(String key) {
    if (key == 'blobURL')
      return blobURL;
    else if (key == 'hasOverlaySurface')
      return hasOverlaySurface;
    else if (key == 'id')
      return id;
    else if (key == 'localURI')
      return localURI;
    else if (key == 'mediaType')
      return mediaType;
    else if (key == 'miniatura')
      return miniatura;
    else if (key == 'overlaySurface')
      return overlaySurface;
    else if (key == 'payload')
      return payload;
    else if (key == 'visPos')
      return visPos;
    else if (key == 'xDocID')
      return xDocID;
    else if (key == 'xDocID_resolved')
      return xDocID_resolved;
    else if (key == 'xDocType') return xDocType;
  }

  @override
  setProp(String key, dynamic newVal) {
    if (key == 'blobURL')
      blobURL = newVal;
    else if (key == 'hasOverlaySurface')
      hasOverlaySurface = newVal;
    else if (key == 'id')
      id = newVal;
    else if (key == 'localURI')
      localURI = newVal;
    else if (key == 'mediaType')
      mediaType = newVal;
    else if (key == 'miniatura')
      miniatura = newVal;
    else if (key == 'overlaySurface')
      overlaySurface = newVal;
    else if (key == 'payload')
      payload = newVal;
    else if (key == 'visPos')
      visPos = newVal;
    else if (key == 'xDocID')
      xDocID = newVal;
    else if (key == 'xDocID_resolved')
      xDocID_resolved = newVal;
    else if (key == 'xDocType') xDocType = newVal;
  }
}

==> xfxwidgets-1.8.43.tar.gz: lib/xMediaItem.dart <==
﻿import 'dart:typed_data';
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:xfxbase/XFDataItem.dart';
import 'package:xfxwidgets/xMediaItem.dart';

///
///XMediaItem
class XMediaItem extends XFDataItem {
  @override
  String? get X_nome => "XMediaItem";
  @override
  String? get X_nomeMF => "F";
  @override
  String? get X_nomePlurale => "XMediaItem";
  @override
  String? get X_docCaption => "XMediaItem";
  static final String tableName = 'XMediaItem';
  static final XProp blobURL_XP = XProp('blobURL', 'bloblURL', Color.fromARGB(255, 0, 0, 0));

  ///
  /// Note:Deciso e fillato da API
  /// 'bloblURL'
  String? blobURL;
  static final XProp hasOverlaySurface_XP = XProp('hasOverlaySurface', 'hasOverlaySurface', Color.fromARGB(255, 0, 0, 0));

  /// 'hasOverlaySurface'
  bool? hasOverlaySurface;
  static final XProp localURI_XP = XProp('localURI', 'localURI', Color.fromARGB(255, 0, 0, 0));

  /// 'localURI'
  String? localURI;
  static final XProp mediaType_XP = XProp('mediaType', 'Tipo', Color.fromARGB(255, 0, 0, 0));

  /// S= sost, U = Usateo, G = generale
  ///
  /// ToolTip:S= sost, U = Usateo, G = generale
  /// 'Tipo'
  int? mediaType;
  static final XProp miniatura_XP = XProp('miniatura', 'miniatura', Color.fromARGB(255, 0, 0, 0));

  /// 'miniatura'
  Uint8List? miniatura;
  static final XProp overlaySurface_XP = XProp('overlaySurface', 'overlaySurface', Color.fromARGB(255, 0, 0, 0));

  /// Bitmap trasp con di segni dell'utente che si sovrappone al payload
  ///
  /// Note:lo svuotiamo nelle API e lo mettiamo nel BLOB
  ///
  /// ToolTip:Bitmap trasp con di segni dell'utente che si sovrappone al payload
  /// 'overlaySurface'
  Uint8List? overlaySurface;
  static final XProp payload_XP = XProp('payload', 'Payload', Color.fromARGB(255, 0, 0, 0));

  ///
  /// Note:lo svuotiamo nelle API e lo mettiamo nel BLOB
  /// 'Payload'
  Uint8List? payload;
  static final XProp visPos_XP = XProp('visPos', 'Pos', Color.fromARGB(255, 0, 0, 0));

  /// 'Pos'
  int? visPos;
  static final XProp xDocID_XP = XProp('xDocID', 'Riferimento', Color.fromARGB(255, 248, 227, 140));

  /// ID del XDoc al quale è legato questo file
  ///
  /// ToolTip:ID del XDoc al quale è legato questo file
  /// 'Riferimento'
  String? xDocID;
  String? xDocID_resolved;
  static final String colnamexDocID_resolved = 'xDocID_resolved';
  static final XProp xDocType_XP = XProp('xDocType', 'xDocType', Color.fromARGB(255, 0, 0, 0));

  /// nome del Attore (XDoc)
  ///
  /// ToolTip:nome del Attore (XDoc)
  /// 'xDocType'
  String? xDocType;

  XMediaItem(super.id, {this.blobURL = "", this.hasOverlaySurface = false, this.localURI = "", this.mediaType = 0, this.miniatura, this.overlaySurface, this.payload, this.visPos = 0, this.xDocID = "", this.xDocID_resolved = "", this.xDocType = "", super.isNew = false}) {}

  factory XMediaItem.fromJson(Map<String, dynamic> jsonData) {
    return XMediaItem(
      jsonData['id'],
      blobURL: jsonData['blobURL'],
      hasOverlaySurface: jsonData['hasOverlaySurface'],
      localURI: jsonData['localURI'],
      mediaType: jsonData['mediaType'] == null ? 0 : int.parse(jsonData['mediaType'].toString()),
      miniatura: (jsonData['miniatura'] == null ? null : base64.decode(jsonData['miniatura'])),
      overlaySurface: (jsonData['overlaySurface'] == null ? null : base64.decode(jsonData['overlaySurface'])),
      payload: (jsonData['payload'] == null ? null : base64.decode(jsonData['payload'])),
      visPos: jsonData['visPos'] == null ? 0 : int.parse(jsonData['visPos'].toString()),
      xDocID: jsonData['xDocID'],
      xDocID_resolved: jsonData['xDocID_resolved'],
      xDocType: jsonData['xDocType'],
    );
  }

  Map<String, dynamic> toJson() => {
        'blobURL': this.blobURL,
        'hasOverlaySurface': this.hasOverlaySurface,
        'id': this.id,
        'localURI': this.localURI,
        'mediaType': this.mediaType,
        'miniatura': this.miniatura,
        'overlaySurface': this.overlaySurface,
        'payload': this.payload,
        'visPos': this.visPos,
        'xDocID_resolved': this.xDocID_resolved,
        'xDocID': this.xDocID == null || this.xDocID == '' ? '00000000-0000-0000-0000-000000000000' : this.xDocID,
        'xDocType': this.xDocType,
      };

  @override
  XMediaItem getCloneFull() {
    var r = XMediaItem(this.id);
    r.copyProps(this, r);
    return r;
  }

  @override
  copyProps(dynamic objectFrom, dynamic objTO) {
    objTO.isNew = objectFrom.isNew;
    objTO.isModified = objectFrom.isModified;

    objTO.blobURL = objectFrom.blobURL;
    objTO.hasOverlaySurface = objectFrom.hasOverlaySurface;
    objTO.id = objectFrom.id;
    objTO.localURI = objectFrom.localURI;
    objTO.mediaType = objectFrom.mediaType;
    objTO.miniatura = objectFrom.miniatura;
    objTO.overlaySurface = objectFrom.overlaySurface;
    objTO.payload = objectFrom.payload;
    objTO.visPos = objectFrom.visPos;
    objTO.xDocID = objectFrom.xDocID;
    objTO.xDocID_resolved = objectFrom.xDocID_resolved;
    objTO.xDocType = objectFrom.xDocType;
  }

  @override
  dynamic getProp(String key) {
    if (key == 'blobURL')
      return blobURL;
    else if (key == 'hasOverlaySurface')
      return hasOverlaySurface;
    else if (key == 'id')
      return id;
    else if (key == 'localURI')
      return localURI;
    else if (key == 'mediaType')
      return mediaType;
    else if (key == 'miniatura')
      return miniatura;
    else if (key == 'overlaySurface')
      return overlaySurface;
    else if (key == 'payload')
      return payload;
    else if (key == 'visPos')
      return visPos;
    else if (key == 'xDocID')
      return xDocID;
    else if (key == 'xDocID_resolved')
      return xDocID_resolved;
    else if (key == 'xDocType') return xDocType;
  }

  @override
  setProp(String key, dynamic newVal) {
    if (key == 'blobURL')
      blobURL = newVal;
    else if (key == 'hasOverlaySurface')
      hasOverlaySurface = newVal;
    else if (key == 'id')
      id = newVal;
    else if (key == 'localURI')
      localURI = newVal;
    else if (key == 'mediaType')
      mediaType = newVal;
    else if (key == 'miniatura')
      miniatura = newVal;
    else if (key == 'overlaySurface')
      overlaySurface = newVal;
    else if (key == 'payload')
      payload = newVal;
    else if (key == 'visPos')
      visPos = newVal;
    else if (key == 'xDocID')
      xDocID = newVal;
    else if (key == 'xDocID_resolved')
      xDocID_resolved = newVal;
    else if (key == 'xDocType') xDocType = newVal;
  }
}
